# Project Overview
The CHART MagNum (Magnum Numerics) aims at introducing advanced design techniques in order to support the design process of superconducting accelerator magnet.
The project responds to the following strategic goals:
- Sustainability

  Ensure that outstanding modeling work will have an impact on present or future designs. This also require that models have clearly defined scope and range of applicability.
- Traceability

  Ensure that the modeler is able to trace back the input parameters, code and script versions, etc., that have been used to produce a particular plot in a ppt or pdf.
  Traceability is even more important in multi-scale and multi-model analysis.
- Repeatability

  Ensure that results presented at, e.g., a Conceptual Design Review can be reproduced at any later time.
  Ensure that as-built models can be re-run at any moment during a potentially decades-long project life cycle.
- Flexibility

  Allow for different labs and collaborators to have/prefer different licenses.
  Enable researchers to implement innovative ideas while building upon existing best practices, but without having to solve legacy issues.
- Usability

  Encapsulate the increased flexibility behind easy-to-use UIs for the standard design work.

The project implements a number of concepts introduced by the MBSE (Model-Based System Engineering) methdology.
In particular, MBSE shifts the focus from documents to models as primary means of communication in complex system design projects.
